#
# spec file for package python-parse
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%{?sle15_python_module_pythons}
Name:           python-parse
Version:        1.20.2
Release:        2.1
Summary:        Python module for parsing strings using a "format" syntax
License:        MIT
URL:            https://github.com/r1chardj0n3s/parse
Source0:        https://files.pythonhosted.org/packages/source/p/parse/parse-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
Parse strings using a specification based on the Python format() syntax.

%prep
%setup -q -n parse-%{version}
chmod a-x README.rst

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/parse.py
%pycache_only %{python_sitelib}/__pycache__/parse.*
%{python_sitelib}/parse-%{version}.dist-info

%changelog
* Thu Sep 26 2024 Thiago Bertoldi <thiago.bertoldi@suse.com>
- use modern python version on Leap15.6
* Thu Jun 20 2024 Dirk Müller <dmueller@suse.com>
- update to 1.20.2:
  * allow hyphen in field name. closes #86
* Thu Feb  1 2024 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pytest, like upstream has.
* Tue Jan 30 2024 Dirk Müller <dmueller@suse.com>
- update to 1.20.1:
  * add formatter property, closes #172
  * add security policy file. closes #175.
  * Support various number of digits after the comma in the
    timestamp %%f …
* Sat Jan 13 2024 Dirk Müller <dmueller@suse.com>
- update to 1.20.0:
  * Optimize _expand_named_fields
  * Add functionality to parse datetimes according C standard
    format codes.
- update to 1.19.1:
  * Add support for sign specifiers in number formats.
  * Fix handling of unused alignment
  * modern packaging
  * universal wheel
* Wed Aug 25 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.19.0
  * Fix using digit field numbering and types
  * match trailing newline (#124)
  * readme: fix style (#126)
  * Add Github Actions config (#129)
  * Docs for slice change
  * Support slice access to results (#128)
- from version 1.18.0
  * Add test for stateful int_convert
  * Make int_convert stateless
- from version 1.17.0
  * Make left- and center-aligned search consume up to next space
  * adding properties to access named fields and fixed fields (#115)
  * Fix findall case_sensitive (#113)
- from version 1.16.0
  * release stuff
  * fixing issue 110 by using functor instead of inner function (#111)
  * add failing test for bug 110
  * Add syntax highlighting to README (#105)
* Sun Mar 15 2020 Tomáš Chvátal <tchvatal@suse.com>
- No need to fetch license anymore, it is in the tarball
* Wed Mar 11 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 1.15.0
  * Several bugs with parsing hex, bin and oct numbers.
  * Handle fortran formatted float number, Bug fix & test case.
  * Handle comparison of FixedTzOffset with other types of object
* Wed Sep 11 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.12.1:
  * no upstream changelog
* Thu Apr 25 2019 pgajdos@suse.com
- version update to 1.12.0
  * Do not assume closing brace when an opening one is found
- added sources
  https://github.com/r1chardj0n3s/parse/issues/82
  + LICENSE
* Thu Feb 14 2019 Matej Cepl <mcepl@suse.com>
- Update to 1.11.1:
  * Implement __contains__ for Result instances.
  * Introduce a "letters" matcher, since "w" matches numbers also.
  * Fix deprecation warnings around backslashes in regex strings
    (thanks Mickaël Schoentgen). Also fix some documentation
    formatting issues.
  * We now honor precision and width specifiers when parsing
    numbers and strings, allowing parsing of concatenated
    elements of fixed width (thanks Julia Signell)
  * Add LICENSE file at request of packagers. Correct handling of
    AM/PM to follow most common interpretation. Correct parsing
    of hexadecimal that looks like a binary prefix. Add ability
    to parse case sensitively. Add parsing of numbers to Decimal
    with "F" (thanks John Vandenberg)
  * Add regex_group_count to with_pattern() decorator to support
    user-defined types that contain brackets/parenthesis (thanks
    Jens Engel)
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sun Jul 29 2018 jengelh@inai.de
- Use noun phrase in summary.
* Thu May 24 2018 toddrme2178@gmail.com
- Spec file cleanups
* Wed Oct 18 2017 toddrme2178@gmail.com
- Implement single-spec version
- Update to version 1.8.2
  * No changelog
* Fri Jun  3 2016 toddrme2178@gmail.com
- Initial version
